@@ -17,6 +17,7 @@ from pyefun.timeUtil import *
 from pyefun.regexpUtil import *
 
 from pyefun.threadingUtil import *
+from pyefun.processPoolUtil import *
 from pyefun.networkUtil import *
 from pyefun.configUtil import *
 from pyefun.configEnvUtil import *
@@ -24,8 +25,9 @@ from pyefun.clockUtil import *
 
 from pyefun.encoding.compress.egzip import *
 from pyefun.encoding.compress.ezlib import *
+from pyefun.encoding.compress.zip import *
 from pyefun.encoding.ebinary.binary import *
 from pyefun.encoding.ebase64.ebase64 import *
 from pyefun.encoding.url.url import *
 
-__version__ = '1.0.17'
\ No newline at end of file
+__version__ = '1.0.23'
\ No newline at end of file
