@@ -1,3 +1,14 @@
+"""
+
+.. Hint::
+    实用函数
+
+.. literalinclude:: ../../../pyefun/commonlyUtil_test.py
+    :language: python
+    :caption: 代码示例
+    :linenos:
+
+"""
 import random
 
 import ubelt as ub
@@ -11,6 +22,8 @@ import uuid
 
 def 取uuid():
     return str(uuid.uuid4())
+
+
 def 取短id():
     array = ["a", "b", "c", "d", "e", "f",
              "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "s",
@@ -28,6 +41,7 @@ def 取短id():
         buffer.append(array[val % 62])
     return "".join(buffer)
 
+
 def 取sha1(data, 哈希算法='sha1'):
     return ub.hash_data(data, hasher=哈希算法)
 
@@ -261,14 +275,15 @@ def 路径_优化路径(path):
     :param path:
     :return:
     """
-    if 寻找文本(path,"\\") > -1:
-        path = 子文本替换(path,"\\","/")
+    if 寻找文本(path, "\\") > -1:
+        path = 子文本替换(path, "\\", "/")
     if 寻找文本(path, r"\\") > -1:
-        path = 子文本替换(path,r"\\","/")
-    if 寻找文本(path,"//") > -1:
-        path = 子文本替换(path,r"//","/")
+        path = 子文本替换(path, r"\\", "/")
+    if 寻找文本(path, r"//") > -1:
+        path = 子文本替换(path, r"//", "/")
     return ub.util_path.normpath(path)
 
+
 def 路径_合并(*path):
     """
     a b c d 合并为 a/b/c/d 并且自动优化路径
@@ -668,3 +683,12 @@ def 结束(*args, **kwargs):
     操作系统需求： Windows、Linux、Unix
     """
     return exit(args, **kwargs)
+
+
+def 运行python代码(代码,全局变量=None,局部变量=None):
+    '动态执行python代码并返回值'
+    return eval(代码,全局变量,局部变量)
+
+def 执行python代码(代码,全局变量=None,局部变量=None):
+    '动态执行python代码,只返回None'
+    return exec(代码,全局变量,局部变量)
\ No newline at end of file
