@@ -1,5 +1,13 @@
 """
-线程操作类
+
+.. Hint::
+    线程操作有线程池
+
+
+.. literalinclude:: ../../../pyefun/threadingUtil_test.py
+    :language: python
+    :caption: 代码示例
+    :linenos:
 
 """
 
@@ -10,7 +18,6 @@ from concurrent.futures import ThreadPoolExecutor
 from threading import current_thread
 
 
-
 @异常处理返回类型逻辑型
 def 启动线程(函数名, 参数=(), 跟随主线程结束=False):
     "成功返回线程对象,参数用元组形式传入,返回线程对象,daemon属性为False，主线程结束时会检测该子线程是否结束"
@@ -184,18 +191,10 @@ def 线程_取主线程():
     return threading.main_thread()
 
 
-
-
-
-
-
 def 取当前线程名称():
     return current_thread().name
 
 
-
-
-
 class 线程池(ThreadPoolExecutor):
     """
     当有大量并发任务需要处理时，再使用传统的多线程就会造成大量的资源创建销毁导致服务器效率的下降。这时候，线程池就派上用场了。线程池技术为线程创建、销毁的开销问题和系统资源不足问题提供了很好的解决方案。
@@ -236,7 +235,13 @@ class 线程池(ThreadPoolExecutor):
             :param 线程初始化函数:
             :param 初始化函数参数:
         """
-        super().__init__(最大线程数量, 线程名称前缀, 线程初始化函数, 初始化函数参数)
+
+        super().__init__(
+            max_workers=最大线程数量,
+            thread_name_prefix=线程名称前缀,
+            initializer=线程初始化函数,
+            initargs=初始化函数参数
+        )
 
     def 投递任务(self, *任务函数, **传入参数):
         """
@@ -273,10 +278,3 @@ class 线程池(ThreadPoolExecutor):
         :return:
         """
         return self.map(任务函数, *任务参数数组, timeout=超时, chunksize=chunksize)
-
-
-
-
-
-
-
