@@ -1,14 +1,21 @@
 """
-时间工具类
-
-时间统计
-"""
 
+.. Hint::
+    时间工具类 时间统计
+
+
+.. literalinclude:: ../../../pyefun/timeUtil_test.py
+    :language: python
+    :caption: 代码示例
+    :linenos:
+
+"""
+
+import datetime
 import time
 import sys
 from .arithmeticOperationBase import *
-from ubelt import *
-import ubelt as ub
+import ubelt.timerit
 from collections import OrderedDict
 
 
@@ -22,18 +29,42 @@ class 时间统计():
     ...
     """
 
-    def __init__(self):
+    def __init__(self, 名称=""):
         self.开始()
+        self.名称 = 名称
+        self.zstart = self.start
+        if self.名称:
+            print("时间统计: %s 开始 %s" % (self.名称, datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")))
 
     def __enter__(self):
         return self
 
     def 开始(self):
+        """
+        重新计算开始时间
+        """
         self.start = time.perf_counter()
 
-    def 取耗时(self):
+    def 取耗时(self, 名称=""):
+        """
+        每次计时后重置 如果需要总耗时的话 取总耗时() 即可
+        """
         self.end = time.perf_counter()
         self.ms = int((self.end - self.start) * 1000)
+        self.开始()
+        if 名称 != "":
+            print("时间统计: %s %s %sms" % (self.名称, 名称, self.ms))
+        elif self.名称 != "":
+            print("时间统计: %s %sms" % (self.名称, self.ms))
+
+        return self.ms
+
+    def 取总耗时(self):
+        """
+        自对象创建以来的总耗时
+        """
+        self.end = time.perf_counter()
+        self.ms = int((self.end - self.zstart) * 1000)
         return self.ms
 
     def 取毫秒(self):
@@ -43,7 +74,8 @@ class 时间统计():
         return self.取耗时() / 1000
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        self.取耗时()
+        if self.名称 != "":
+            print("时间统计: %s 结束 %sms %s" % (self.名称, self.取总耗时(), datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")))
         return exc_type is None
 
 
@@ -51,10 +83,11 @@ def 计时器():
     return 时间统计()
 
 
-class 计时统计(ub.Timerit):
+class 计时统计(ubelt.timerit.Timerit):
     """
     计代码块的平均时间
     """
+
     def __init__(self, 次数=1, 标签=None, 取样=3, 单位=None, 显示信息=None):
         self.t = super().__init__(次数, 标签, 取样, 单位, 显示信息)
 
