@@ -37,14 +37,28 @@ class TestTimeUtil(unittest.TestCase):
         print(t.取毫秒())
 
     def test_2(self):
-        for _ in 计时统计(num=1000, verbose=3):
+        for _ in 计时统计(次数=1000, 显示信息=3):
             math.factorial(10000)
 
     def test_3(self):
-        t1 = 计时统计(次数=100, 标签="运行", 取样=20, 显示信息=3, 单位='ms')
+        t1 = 计时统计(次数=10, 标签="运行", 取样=20, 显示信息=3, 单位='ms')
         for timer in t1:
             setup_vars = 10000
             with timer:
-                延时(0.01 + 取随机数(1, 2)/100)
+                延时(0.01 + 取随机数(1, 2) / 10)
                 math.factorial(setup_vars)
         print('总耗时 = %r' % (t1.取耗时(),))
+
+    def test_4(self):
+        with 时间统计("买东西业务") as t:
+            延时(1)
+            t.取耗时("出门")
+            延时(1)
+            t.取耗时("到店")
+            延时(1)
+            t.取耗时("购买")
+        print("总耗时", t.取总耗时())
+
+    def test_5(self):
+        with 时间统计("测试耗时"):
+            延时(1)
